@@ -3,7 +3,7 @@
 
 """
 Configure the sensor for continuous measurement with rates,
-sampling counts and mode optmized for low power, as recommended
+sampling counts and mode optimized for low power, as recommended
 in Infineon's datasheet:
 https://www.infineon.com/dgdl/Infineon-DPS310-DS-v01_00-EN.pdf
 """
@@ -14,18 +14,17 @@ https://www.infineon.com/dgdl/Infineon-DPS310-DS-v01_00-EN.pdf
 
 import time
 import board
-import adafruit_dps310
+from adafruit_dps310 import advanced
 
 i2c = board.I2C()  # uses board.SCL and board.SDA
-
-dps310 = adafruit_dps310.DPS310(i2c)
+dps310 = advanced.DPS310_Advanced(i2c)
 
 dps310.reset()
-dps310.pressure_oversample_count = adafruit_dps310.SampleCount.COUNT_2
-dps310.pressure_rate = adafruit_dps310.Rate.RATE_1_HZ
-dps310.temperature_oversample_count = adafruit_dps310.SampleCount.COUNT_16
-dps310.temperature_rate = adafruit_dps310.Rate.RATE_1_HZ
-dps310.mode = adafruit_dps310.Mode.CONT_PRESTEMP
+dps310.pressure_oversample_count = advanced.SampleCount.COUNT_2
+dps310.pressure_rate = advanced.Rate.RATE_1_HZ
+dps310.temperature_oversample_count = advanced.SampleCount.COUNT_16
+dps310.temperature_rate = advanced.Rate.RATE_1_HZ
+dps310.mode = advanced.Mode.CONT_PRESTEMP
 dps310.wait_temperature_ready()
 dps310.wait_pressure_ready()
 
